intros-MaxEnt
=============

**The Whole Tale Project**

Author: Santiago Nunez-Corrales
        (nunezco2@illinois.edu)


**intros-MaxEnt** is a Python software package that provides an open
implementation of the MaxEnt algorithm for ecological niche modeling
as described in

    Phillips, S. J., Anderson, R. P., & Schapire, R. E. (2006). Maximum
    entropy modeling of species geographic distributions.
    Ecological modelling, 190(3-4), 231-259.

Our goal with this package is, scientifically, to help improve the
modeling landscape in ecological niche modeling by making explicit the
consequences of varying various parameters in MaxEnt based on
biologically informed hypotheses.

The packaged provides facilities for the following tasks:

1. Importing georeferenced data from taxa records for modeling species
   distribution, as well as environmental variables data for locations
   compliant with WGS84 latitude-longitude coordinates.
2. Executing the MaxEnt algorithm with inspection and reparametrization
   capabilities of models and outcomes.
3. Analyzing and differentially comparing model outcomes including KML
   and PNG image generation at various resolutions.
4. Packaging of model configurations and experiments for extended
   scientific replication.

This package is also intended to be used in Jupyter Notebooks at The
Whole Tale environment as an example of scientific reproducibility. The
current software implementation was heavily informed by

    Merow, C., Smith, M. J., & Silander, J. A. (2013). A practical guide
    to MaxEnt for modeling species’ distributions: what it does, and why
    inputs and settings matter. Ecography, 36(10), 1058-1069.

This code is part of The Whole Tale Summer Internship 2018.
